% MATLAB SIMULATION OF NSA FS-1016 CELP v3.2
% COPYRIGHT (C) 1995-99 ANDREAS SPANIAS AND TED PAINTER
%
% This Copyright applies only to this particular MATLAB implementation
% of the FS-1016 CELP coder.  The MATLAB software is intended only for educational
% purposes.  No other use is intended or authorized.  This is not a public
% domain program and distribution to individuals or networks is strictly
% prohibited.  Be aware that use of the standard in any form is goverened
% by rules of the US DoD.  Therefore patents and royalties may apply to
% authors, companies, or committees associated with this standard, FS-1016.  For
% questions regarding the MATLAB implementation please contact Andreas
% Spanias at (480) 965-1837.  For questions on rules,
% royalties, or patents associated with the standard, please contact the DoD.
%
% ALL DERIVATIVE WORKS MUST INCLUDE THIS COPYRIGHT NOTICE.
%
% ******************************************************************
% BWEXP
%
% PORTED TO MATLAB FROM CELP 3.2a C RELEASE
% 6-9-94
%
% ******************************************************************
%
% DESCRIPTION
%
% Bandwidth expansion of LPC predictor coefficients
%
% DESIGN NOTES
%
% Subroutine to perform bandwidth modification by moving the poles
% (or zeros) radially in the z plane.  If the bandwidth expansion
% factor (alpha) is less than unity, the bandwidths are expanded by
% shifting the poles (or zeros) toward the origin of the z plane.
% The predictor coefficients are scaled directly according to:
%
%                i-1
%   a' = a  alpha               where i = 1, . . . , order+1
%    i    i
%
% This results in a bandwidth expansion of:
%
%   -(fs/pi)ln(alpha) Hz
%
%   (e.g., fs = 8 kHz, alpha = 0.994127 -> 15 Hz bandwidth expansion)
%
% LPC predictor coefficient convention is:
%
%          p+1        -(i-1)
%   A(z) = SUM   a   z          where a  = +1.0
%          i=1    i                    1
%
% VARIABLES
%
% INPUTS
%   pc       -    Predictor coefficients
%   alpha    -    Bandwidth expansion factor for LPC poles
%   n        -    Predictor order
%
% OUTPUTS
%   pcexp    -    Expanded predictor coefficients
%
% ******************************************************************

function pcexp = bwexp( alpha, pc, n )

% SCALE PREDICTOR COEFFICIENTS TO SHIFT POLES RADIALLY INWARD
pcexp( 1:n+1, 1 ) = ( pc( 1:n+1 ) .* ( alpha .^ (0:n)' ) );
