% MATLAB SIMULATION OF NSA FS-1016 CELP v3.2
% COPYRIGHT (C) 1995-99 ANDREAS SPANIAS AND TED PAINTER
%
% This Copyright applies only to this particular MATLAB implementation
% of the FS-1016 CELP coder.  The MATLAB software is intended only for educational
% purposes.  No other use is intended or authorized.  This is not a public
% domain program and distribution to individuals or networks is strictly
% prohibited.  Be aware that use of the standard in any form is goverened
% by rules of the US DoD.  Therefore patents and royalties may apply to
% authors, companies, or committees associated with this standard, FS-1016.  For
% questions regarding the MATLAB implementation please contact Andreas
% Spanias at  (602) 965-1837.  For questions on rules,
% royalties, or patents associated with the standard, please contact the DoD.
%
% ALL DERIVATIVE WORKS MUST INCLUDE THIS COPYRIGHT NOTICE.
%
% ******************************************************************
% CLIP
%
% PORTED TO MATLAB FROM CELP 3.2a C RELEASE
% 8-10-94
%
% ******************************************************************
%
% DESCRIPTION
%
% Determine if coder output is clipped
%
% DESIGN NOTES
%
% Clipping heuristics taken from NSA CELP 3.2a release
%
% VARIABLES
%
% INPUTS
%   s           -    Input speech (coder output, postfiltered)
%
% OUTPUTS
%   clipped     -    Clipping status flag
%
% INTERNALS
%   ClipCount   -    Total number of clipped samples in current subframe
%   ClipSum     -    Summation of clipped samples
%   sab         -    Vector, magnitude of s
%
% CONSTANTS
%   TRUE        -    Boolean flag
%   FALSE       -    Boolean flag
%
% ******************************************************************

function clipped = clip( s )

% DECLARE GLOBALS
global TRUE FALSE

% ASSUME NO CLIPPING
clipped = FALSE;

% GENERATE CLIPPING TEST PARAMETERS
sab = abs(s);
ClipCount = sum( sab > 32768 );
ClipSum = sum( sab( find( sab > 32768) ) );

% APPLY CLIPPING HEURISTICS
if ( ClipCount >= 10 ) | ( ( ClipSum > 1.0e6 ) & ( ClipCount >= 5 ) )
    clipped = TRUE;
end
