% MATLAB SIMULATION OF NSA FS-1016 CELP v3.2
% COPYRIGHT (C) 1995-99 ANDREAS SPANIAS AND TED PAINTER
%
% This Copyright applies only to this particular MATLAB implementation
% of the FS-1016 CELP coder.  The MATLAB software is intended only for educational
% purposes.  No other use is intended or authorized.  This is not a public
% domain program and distribution to individuals or networks is strictly
% prohibited.  Be aware that use of the standard in any form is goverened
% by rules of the US DoD.  Therefore patents and royalties may apply to
% authors, companies, or committees associated with this standard, FS-1016.  For
% questions regarding the MATLAB implementation please contact Andreas
% Spanias at (602) 965-1837.  For questions on rules,
% royalties, or patents associated with the standard, please contact the DoD.
%
% ALL DERIVATIVE WORKS MUST INCLUDE THIS COPYRIGHT NOTICE.
%
% ******************************************************************
% COR
%
% PORTED TO MATLAB FROM CELP 3.2a C RELEASE
% 6-8-94
%
% ******************************************************************
%
% DESCRIPTION
%
% Compute autocorrelation lags
%
% DESIGN NOTES
%
% Computes autocorrelation coefficients of data sequence rar:
%
%            idim
%     C(i) = SUM   rar(k) * rar(k-i)   , where i = 0, ..., n lags
%            k=i+1
%
%     c0 = C(0)
%
% NOTE:  rar(k-i) is truncated, so C(i) are true autocorrelations.
%
% VARIABLES
%
% INPUTS
%   rar      -      Input data
%   idim     -      Frame size
%   n        -      Number of autocorrelation lags, exclusive c0
%
% OUTPUTS
%   c0       -      C(0)
%   c        -      Autocorrelation terms C(i), i = 1,2,...,n
%
% INTERNALS
%   i        -      Lag index
%
% ******************************************************************

function [ c0, c ] = cor( rar, idim, n )

% ALLOCATE RETURN VECTOR
c = zeros( n, 1 );

% COMPUTE C(0)
c0 = sum( rar(1:idim) .* rar(1:idim) );

% COMPUTE C(i), i NONZERO
for i = 1:n
    c(i) = sum( rar(i+1:idim) .* rar(1:idim-i) );
end


