% MATLAB SIMULATION OF NSA FS-1016 CELP v3.2
% COPYRIGHT (C) 1995-99 ANDREAS SPANIAS AND TED PAINTER
%
% This Copyright applies only to this particular MATLAB implementation
% of the FS-1016 CELP coder.  The MATLAB software is intended only for educational
% purposes.  No other use is intended or authorized.  This is not a public
% domain program and distribution to individuals or networks is strictly
% prohibited.  Be aware that use of the standard in any form is goverened
% by rules of the US DoD.  Therefore patents and royalties may apply to
% authors, companies, or committees associated with this standard, FS-1016.  For
% questions regarding the MATLAB implementation please contact Andreas
% Spanias at  (602) 965-1837.  For questions on rules,
% royalties, or patents associated with the standard, please contact the DoD.
%
% ALL DERIVATIVE WORKS MUST INCLUDE THIS COPYRIGHT NOTICE.
%
% ******************************************************************
% CPACK
%
% PORTED TO MATLAB FROM CELP 3.2a C RELEASE
% 6-17-94
%
% ******************************************************************
%
% DESCRIPTION
%
% Pack input data into a bitstream array
%
% DESIGN NOTES
%
% Employs two's complement binary encoding.  Upon exit, pointer indexes
% the position of the next new bit to enter the bit stream.
%
% VARIABLES
%
% INPUTS
%   value      -     Decimal value(s) to be encoded
%   bits       -     Number of bits with which to encode the input(s)
%   pointer    -     Bit stream array index
%   array      -     Bit stream array
%
% OUTPUTS
%   array      -     Bit stream array
%   pointer    -     Updated bit stream array index
% 
% INTERNALS
%   last       -     Index of last bit in the stream
%
% ******************************************************************

function [ array, pointer ] = cpack( value, bits, pointer, array )

% PACK EACH ITEM INTO THE BITSTREAM
for i = 1:length(bits)
    last = pointer+bits(i)-1;
    array( last:-1:pointer ) = ( int2bin( value(i), bits(i) ) )';
    pointer = last + 1;
end

