% MATLAB SIMULATION OF NSA FS-1016 CELP v3.2
% COPYRIGHT (C) 1995-99 ANDREAS SPANIAS AND TED PAINTER
%
% This Copyright applies only to this particular MATLAB implementation
% of the FS-1016 CELP coder.  The MATLAB software is intended only for educational
% purposes.  No other use is intended or authorized.  This is not a public
% domain program and distribution to individuals or networks is strictly
% prohibited.  Be aware that use of the standard in any form is goverened
% by rules of the US DoD.  Therefore patents and royalties may apply to
% authors, companies, or committees associated with this standard, FS-1016.  For
% questions regarding the MATLAB implementation please contact Andreas
% Spanias at (602) 965-1837.  For questions on rules,
% royalties, or patents associated with the standard, please contact the DoD.
%
% ALL DERIVATIVE WORKS MUST INCLUDE THIS COPYRIGHT NOTICE.
%
% ******************************************************************
% DCODPG
%
% PORTED TO MATLAB FROM CELP 3.2a C RELEASE
% 8-4-94
%
% ******************************************************************
%
% DESCRIPTION
%
% Decodes all pitch gain values for a frame
%
% DESIGN NOTES
%
% Converts pitch gain bits from the bit stream to actual pitch gains,
% using table lookups.
%
% VARIABLES
%
% INPUTS
%   pgbits     -     Number of bits allocated for pgain quantization
%   bitsum1    -     Number of bits for odd subframes
%   bitsum2    -     Number of bits for even subframes
%   bitpointer -     Number of bits used
%   nn         -     Number of subframes
%   stream     -     Bit stream
%
% OUTPUTS
%   pgs        -     Vector of pitch gains
%   bitpointer -     Number of bits used
%
% INTERNALS
%   i          -     Subframe counter
%   index      -     Unpacked index into pitch gain decoding table
%
% GLOBALS
%   pitch2max5 -     Pitch gain decoding table
%
% ******************************************************************

function [ pgs, bitpointer ] = dcodpg( pgbits, bitsum1, bitsum2, ...
                                       bitpointer, nn, stream )

% DECLARE GLOBAL VARIABLES
global pitch2max5

% INIT RETURN VECTOR
pgs = zeros( nn, 1 );

% ESTABLISH STARTING BIT STREAM POSITION
pointer = bitpointer;

% RUN DECODING FOR ALL SUBFRAMES
for i = 1:nn
    [ index, pointer ] = unpack( stream, pgbits, pointer );
    pgs(i) = pitch2max5( index+1 );

    % MAINTAIN BITSTREAM POINTER
    if ( i == 1 ) | ( i == 3 ) | ( i == 5 )
        pointer = pointer + bitsum2 - pgbits;
    elseif ( i == 2 ) | ( i == 4 ) | ( i == 6 )
        pointer = pointer + bitsum1 - pgbits;
    else
        fprintf( 'dcodpg: Error in decoding pitch gain\n' );
    end
end

% UPDATE BIT STREAM INDEX
bitpointer = bitpointer + pgbits;

