% MATLAB SIMULATION OF NSA FS-1016 CELP v3.2
% COPYRIGHT (C) 1995-99 ANDREAS SPANIAS AND TED PAINTER
%
% This Copyright applies only to this particular MATLAB implementation
% of the FS-1016 CELP coder.  The MATLAB software is intended only for educational
% purposes.  No other use is intended or authorized.  This is not a public
% domain program and distribution to individuals or networks is strictly
% prohibited.  Be aware that use of the standard in any form is goverened
% by rules of the US DoD.  Therefore patents and royalties may apply to
% authors, companies, or committees associated with this standard, FS-1016.  For
% questions regarding the MATLAB implementation please contact Andreas
% Spanias at (602) 965-1837.  For questions on rules,
% royalties, or patents associated with the standard, please contact the DoD.
%
% ALL DERIVATIVE WORKS MUST INCLUDE THIS COPYRIGHT NOTICE.
%
% ******************************************************************
% GAINCODE
%
% PORTED TO MATLAB FROM CELP 3.2a C RELEASE
% 7-14-94
%
% ******************************************************************
%
% DESCRIPTION
%
% Encode and quantize stochastic codebook gain
%
% DESIGN NOTES
%
% Implements codebook gain quantizer to allow practical quantization
% inside the codebook search loop.  Although the 'C' and other
% implementations of this algorithm use a binary tree search
% to minimize complexity and the real time MIPS requirements,
% it is much easier in MATLAB to use the min operator and leave
% specifics of the search algorithm (linear vs. binary searching)
% to MATLAB.
%
% Any savings in execution time afforded by binary tree search were
% insignificant relative to the codebook search times.
%
% VARIABLES
%
% INPUTS
%   input      -     Codebook gain input (unquantized or true value)
%
% OUTPUTS
%   index      -     Quantized codebook gain index
%   qcgain     -     Quantized codebook gain value
%
% GLOBALS
%   gainlog5   -     Logarithmic, 5-bit quantization table
%
% ******************************************************************

function [ index, qcgain ] = gaincode( input )

% DECLARE GLOBALS
global gainlog5

% QUANTIZE INPUT TO NEAREST VALUE IN GAINLOG5 TABLE
[ qcgain, index ] = min( abs( input - gainlog5 ) );

% RETURN QUANTIZED VALUE TO CALLER
qcgain = gainlog5( index );

% CORRECT INDICIES TO MATCH C LANGUAGE RESULTS FOR EASE OF TEST/VERIFICATION
index = index - 1;

