% MATLAB SIMULATION OF NSA FS-1016 CELP v3.2
% COPYRIGHT (C) 1995-99 ANDREAS SPANIAS AND TED PAINTER
%
% This Copyright applies only to this particular MATLAB implementation
% of the FS-1016 CELP coder.  The MATLAB software is intended only for educational
% purposes.  No other use is intended or authorized.  This is not a public
% domain program and distribution to individuals or networks is strictly
% prohibited.  Be aware that use of the standard in any form is goverened
% by rules of the US DoD.  Therefore patents and royalties may apply to
% authors, companies, or committees associated with this standard, FS-1016.  For
% questions regarding the MATLAB implementation please contact Andreas
% Spanias at (602) 965-1837.  For questions on rules,
% royalties, or patents associated with the standard, please contact the DoD.
%
% ALL DERIVATIVE WORKS MUST INCLUDE THIS COPYRIGHT NOTICE.
%
% ******************************************************************
% GUISTAT
%
% NSA CELP 3.2a SPEECH CODER GRAPHICAL USER INTERFACE (GUI)
% 4-28-94
%
% REVISED TO IMPROVE SPEED
% 8-15-94
%
% ******************************************************************
%
% DESCRIPTION
%
% Updates simulation status information in status window during
% non-interactive simulations (no graphical output).
%
% DESIGN NOTES
%
% Computes percent complete in terms of frames remaining to be processed.
%
% VARIABLES
%
% INPUTS
%   none
%
% OUTPUTS
%   none
%
% INTERNALS
%   StatStr    -   Status string
%   Pcomp      -   Percent complete (simulation overall, in terms of frames)
%   px         -   Percent complete bar graph x boundaries
%   py         -   Percent complete bar graph y boundaries
%
% GLOBALS
%   guiSline   -   Handle for status line object
%   guiFrames  -   Total number of frames in input speech file
%   FrameCnt   -   Current frame number
%
% ******************************************************************

function guistat

global guiSline FrameCnt guiFrames;

% DISPLAY NEW STATUS
StatStr = sprintf( 'Processing Frame %3d of %3d', FrameCnt, guiFrames );
set( guiSline, 'string', StatStr );

% COMPUTE PERCENT COMPLETE AND UPDATE BAR GRAPH
Pcomp = (FrameCnt/guiFrames) * 100;
px = [0,0,Pcomp,Pcomp];
py = [0,1,1,0];
patch(px,py,'b');
if ( rem(FrameCnt, 3) == 0 ) | ( FrameCnt == guiFrames )
    drawnow;
end
