% MATLAB SIMULATION OF NSA FS-1016 CELP v3.2
% COPYRIGHT (C) 1995-99 ANDREAS SPANIAS AND TED PAINTER
%
% This Copyright applies only to this particular MATLAB implementation
% of the FS-1016 CELP coder.  The MATLAB software is intended only for educational
% purposes.  No other use is intended or authorized.  This is not a public
% domain program and distribution to individuals or networks is strictly
% prohibited.  Be aware that use of the standard in any form is goverened
% by rules of the US DoD.  Therefore patents and royalties may apply to
% authors, companies, or committees associated with this standard, FS-1016.  For
% questions regarding the MATLAB implementation please contact Andreas
% Spanias at  (602) 965-1837.  For questions on rules,
% royalties, or patents associated with the standard, please contact the DoD.
%
% ALL DERIVATIVE WORKS MUST INCLUDE THIS COPYRIGHT NOTICE.
%
% ******************************************************************
% HAM
%
% PORTED TO MATLAB FROM CELP 3.2a C RELEASE
% 6-7-94
%
% ******************************************************************
%
% DESCRIPTION
%
% Creates a hamming window sequence
%
% DESIGN NOTES
%
% Implements standard hamming window definition.
%
% VARIABLES
%
% INPUTS
%   n        -      Number of points in the window
%
% OUTPUTS
%   win      -      Hamming window samples
%
% INTERNAL
%   hscl     -      Hamming window scale factor
%
% ******************************************************************

function win = ham( n )

% CREATE HAMMING WINDOW SEQUENCE
hscl = 2.0 * pi / ( n-1 );
win = 0.54 - ( 0.46 * cos( hscl*( 0:n-1 ) ) );
win = win';



