% MATLAB SIMULATION OF NSA FS-1016 CELP v3.2
% COPYRIGHT (C) 1995-99 ANDREAS SPANIAS AND TED PAINTER
%
% This Copyright applies only to this particular MATLAB implementation
% of the FS-1016 CELP coder.  The MATLAB software is intended only for educational
% purposes.  No other use is intended or authorized.  This is not a public
% domain program and distribution to individuals or networks is strictly
% prohibited.  Be aware that use of the standard in any form is goverened
% by rules of the US DoD.  Therefore patents and royalties may apply to
% authors, companies, or committees associated with this standard, FS-1016.  For
% questions regarding the MATLAB implementation please contact Andreas
% Spanias at (602) 965-1837.  For questions on rules,
% royalties, or patents associated with the standard, please contact the DoD.
%
% ALL DERIVATIVE WORKS MUST INCLUDE THIS COPYRIGHT NOTICE.
%
% ******************************************************************
% IMPULSE
%
% PORTED TO MATLAB FROM CELP 3.2a C RELEASE
% 6-22-94
%
% ******************************************************************
%
% DESCRIPTION
%
% Compute impulse resopnse of direct form filter
%
% DESIGN NOTES
%
% Exclude adaptive codebook contribution
%
% VARIABLES
%
% INPUTS
%   l          -     Length of impulse response
%
% INTERNALS
%   fctemp     -     Bandwidth expanded predictor poles
%   d5         -     Filter memory
%
% GLOBALS
%   h          -     Impulse response, 1/A(Z)
%   no         -     Predictor order
%   fc         -     Predictor coefficients
%   gamma2     -     Bandwidth expansion coefficient
%
% ******************************************************************

function impulse( l )

% DECLARE GLOBALS
global h no fc gamma2

% INIT UNIT IMPULSE VECTOR AND LOCAL VARIABLES
h = zeros( l, 1 );
h(1) = 1.0;
d5 = zeros( no+1, 1 );

% EXPAND POLE BANDWIDTHS AND GENERATE IMPULSE RESPONSE
fctemp = bwexp( gamma2, fc, no );
[ d5, h ] = polefilt( fctemp, no, d5, h, l );
