% MATLAB SIMULATION OF NSA FS-1016 CELP v3.2
% COPYRIGHT (C) 1995-99 ANDREAS SPANIAS AND TED PAINTER
%
% This Copyright applies only to this particular MATLAB implementation
% of the FS-1016 CELP coder.  The MATLAB software is intended only for educational
% purposes.  No other use is intended or authorized.  This is not a public
% domain program and distribution to individuals or networks is strictly
% prohibited.  Be aware that use of the standard in any form is goverened
% by rules of the US DoD.  Therefore patents and royalties may apply to
% authors, companies, or committees associated with this standard, FS-1016.  For
% questions regarding the MATLAB implementation please contact Andreas
% Spanias at (602) 965-1837.  For questions on rules,
% royalties, or patents associated with the standard, please contact the DoD.
%
% ALL DERIVATIVE WORKS MUST INCLUDE THIS COPYRIGHT NOTICE.
%
% ******************************************************************
% QD
%
% PORTED TO MATLAB FROM CELP 3.2a C RELEASE
% 7-5-94
%
% ******************************************************************
%
% DESCRIPTION
%
% QUANTIZE THE FRACTIONAL PITCH DELAY (D FUNCTION)
%
% VARIABLES
%
% INPUTS
%   d          -     Fractional pitch delay
%
% OUTPUTS
%   q          -     Quantized pitch delay index
%
% INTERNALS
%   qvals      -     Quantized values of d
%
% GLOBALS
%   dfrac      -     Quantized fractional delays (5)
%
% ******************************************************************

function q = qd( d )

% DECLARE GLOBALS
global dfrac

% QUANTIZE D TO NEAREST VALUE IN DFRAC TABLE
qvals = find( abs( d - dfrac ) < 1.0e-2 );

% TRAP ILL-CONDITIONED VALUES OF D
if length( qvals ) == 0
    fprintf( 'delay: Invalid pitch delay = %f\n', d );
end

% RETURN LARGEST QUANTIZED VALUE
q = qvals( length(qvals) );