% MATLAB SIMULATION OF NSA FS-1016 CELP v3.2
% COPYRIGHT (C) 1995-99 ANDREAS SPANIAS AND TED PAINTER
%
% This Copyright applies only to this particular MATLAB implementation
% of the FS-1016 CELP coder.  The MATLAB software is intended only for educational
% purposes.  No other use is intended or authorized.  This is not a public
% domain program and distribution to individuals or networks is strictly
% prohibited.  Be aware that use of the standard in any form is goverened
% by rules of the US DoD.  Therefore patents and royalties may apply to
% authors, companies, or committees associated with this standard, FS-1016.  For
% questions regarding the MATLAB implementation please contact Andreas
% Spanias at (480) 965-1837.  For questions on rules,
% royalties, or patents associated with the standard, please contact the DoD.
%
% ALL DERIVATIVE WORKS MUST INCLUDE THIS COPYRIGHT NOTICE.
%
% ******************************************************************
% UNPACK
%
% PORTED TO MATLAB FROM CELP 3.2a C RELEASE
% 7-29-94
%
% ******************************************************************
%
% DESCRIPTION
%
% Convert m, n-bit binary words into m decimal values
%
% DESIGN NOTES
%
% Employs two's complement binary decoding.  Upon exit, pointer indexes
% the position of the next bit to unpack from the bit stream.
%
% VARIABLES
%
% INPUTS
%   array      -     Bit stream array
%   bits       -     Vector of bit lengths with which to decode the output(s)
%   pointer    -     Bit stream array index
%
% OUTPUTS
%   value      -     Vector of unpacked decimal values (m elements)
%   pointer    -     Updated bit stream array index
%
% INTERNALS
%   last       -     Index of last bit in the stream
%   i          -     Loop index variable
%
% ******************************************************************

function [ value, pointer ] = unpack( array, bits, pointer )

% INIT RETURN VECTOR
value = zeros( length(bits), 1 );

% UNPACK EACH ITEM FROM THE BITSTREAM
for i = 1:length(bits)
    last = pointer+bits(i);
    value(i) = bin2int( [ 0; array( last:-1:pointer+1 ) ]' );
    pointer = last;
end
