% MATLAB SIMULATION OF NSA FS-1016 CELP v3.2
% COPYRIGHT (C) 1995-99 ANDREAS SPANIAS AND TED PAINTER
%
% This Copyright applies only to this particular MATLAB implementation
% of the FS-1016 CELP coder.  The MATLAB software is intended only for educational
% purposes.  No other use is intended or authorized.  This is not a public
% domain program and distribution to individuals or networks is strictly
% prohibited.  Be aware that use of the standard in any form is goverened
% by rules of the US DoD.  Therefore patents and royalties may apply to
% authors, companies, or committees associated with this standard, FS-1016.  For
% questions regarding the MATLAB implementation please contact Andreas
% Spanias at (480) 965-1837.  For questions on rules,
% royalties, or patents associated with the standard, please contact the DoD.
%
% ALL DERIVATIVE WORKS MUST INCLUDE THIS COPYRIGHT NOTICE.
%
% ******************************************************************
% VDECODE
%
% PORTED TO MATLAB FROM CELP 3.2a C RELEASE
% 8-5-94
%
% ******************************************************************
%
% DESCRIPTION
%
% Create stochastic excitation vector from codebook index and
% decoded gain.
%
% DESIGN NOTES
%
% Stochastic excitation vector is combined with pitch vector to
% form LPC excitation.
%
% VARIABLES
%
% INPUTS
%   decodedgain  -     Smoothed stochastic codebook gain
%   l            -     Code word size (excitation vector)
%   cbindex      -     Decoded codebook index
%
% OUTPUTS
%   vdecoded     -     Decoded excitation vector (scaled code word)
%
% INTERNALS
%   codeword     -     Index into StochCB, the stochastic codebook
%
% GLOBALS
%   StochCB      -     Stochastic codebook
%   FrameCnt     -     Current frame
%
% CONSTANTS
%   MAXNCSIZE    -     Maximum stochastic codebook size
%
% ******************************************************************

function vdecoded = vdecode( decodedgain, l, cbindex )

% DECLARE GLOBAL VARIABLES
global StochCB FrameCnt

% DECLARE GLOBAL CONSTANTS
global MAXNCSIZE

% ALLOCATE RETURN VECTOR
vdecoded = zeros( l, 1 );

% COMPUTE CODEWORD INDEX
codeword = ( 2 * ( MAXNCSIZE - cbindex ) ) + 1;

% VALDIATE CODEWORD INDEX
if codeword < 1
    fprintf( 'vdecode: cbindex > MAXNCSIZE @ frame %d\n', FrameCnt );
    codeword = 1;
end

% SCALE AND COPY SELECTED CODEWORD TO EXCITATION VECTOR
vdecoded = StochCB( codeword:codeword+l-1 ) * decodedgain;
