% MATLAB SIMULATION OF NSA FS-1016 CELP v3.2
% COPYRIGHT (C) 1995-99 ANDREAS SPANIAS AND TED PAINTER
%
% This Copyright applies only to this particular MATLAB implementation
% of the FS-1016 CELP coder.  The MATLAB software is intended only for educational
% purposes.  No other use is intended or authorized.  This is not a public
% domain program and distribution to individuals or networks is strictly
% prohibited.  Be aware that use of the standard in any form is goverened
% by rules of the US DoD.  Therefore patents and royalties may apply to
% authors, companies, or committees associated with this standard, FS-1016.  For
% questions regarding the MATLAB implementation please contact Andreas
% Spanias at  (480) 965-1837.  For questions on rules,
% royalties, or patents associated with the standard, please contact the DoD.
%
% ALL DERIVATIVE WORKS MUST INCLUDE THIS COPYRIGHT NOTICE.
%
% ******************************************************************
% WAVHDR
% 1-18-95
%
% ******************************************************************
%
% DESCRIPTION
%
% Create .WAV file header
%
% DESIGN NOTES
%
% Creates wave file header for 16-bit, 8 kHz, mono .WAV file
%
% VARIABLES
%
% INPUTS
%   fpo             -   Output file pointer
%   frames          -   Number of output frames
%   frameSize       -   Output frame size (samples per frame)
%   fmt             -   Data for format specific field (LPC, CELP, etc.)
%
% OUTPUTS
%   status          -   Success or failure
%
% INTERNALS
%   c               -   Condition codes
%
% ******************************************************************

function status = wavhdr( fpo, frames, frameSize, fmt )

% INIT CONSTANTS
WAVHDRSIZE = 44;

% CREATE WAVE FILE HEADER
c = zeros(14,1);
dLen = frames * frameSize * 2;
rLen = dLen + WAVHDRSIZE - 8;
c(1) = fwrite( fpo, 'RIFF', 'char' );             % rId
c(2) = fwrite( fpo, rLen, 'long' );               % rLen
c(3) = fwrite( fpo, 'WAVE', 'char');              % wId
c(4) = fwrite( fpo, 'fmt ', 'char');              % fId
c(5) = fwrite( fpo, 16+length(fmt), 'long');      % fLen = 16 + fmtSpecific field
c(6) = fwrite( fpo, 1, 'short');                  % wfmtTag (1=PCM)
c(7) = fwrite( fpo, 1, 'short');                  % nchan
c(8) = fwrite( fpo, 8000, 'long');                % nSampSec
c(9) = fwrite( fpo, 16000, 'long');               % nAvgBytesSec
c(10) = fwrite( fpo, 2, 'short');                 % nBlkAlign
c(11) = fwrite( fpo, 16, 'short');                % fmtSpecific field - bits/sample
c(12) = fwrite( fpo, fmt, 'char');                % fmtSpecific field - bits/sample
c(13) = fwrite( fpo, 'data', 'char' );            % dId
c(14) = fwrite( fpo, dLen, 'long' );              % dLen

% CHECK CONDITION CODES
if sum(c) ~= 25 + length(fmt)
    status = 0;
else
    status = 1;
end
