% MATLAB SIMULATION OF NSA FS-1016 CELP v3.2
% COPYRIGHT (C) 1995-99 ANDREAS SPANIAS AND TED PAINTER
%
% This Copyright applies only to this particular MATLAB implementation
% of the FS-1016 CELP coder.  The MATLAB software is intended only for educational
% purposes.  No other use is intended or authorized.  This is not a public
% domain program and distribution to individuals or networks is strictly
% prohibited.  Be aware that use of the standard in any form is goverened
% by rules of the US DoD.  Therefore patents and royalties may apply to
% authors, companies, or committees associated with this standard, FS-1016.  For
% questions regarding the MATLAB implementation please contact Andreas
% Spanias at (480) 965-1837.  For questions on rules,
% royalties, or patents associated with the standard, please contact the DoD.
%
% ALL DERIVATIVE WORKS MUST INCLUDE THIS COPYRIGHT NOTICE.
%
% ******************************************************************
% ZEROFILT
%
% PORTED TO MATLAB FROM CELP 3.2a C RELEASE
% 6-22-94
%
% ******************************************************************
%
% DESCRIPTION
%
% Direct form FIR filter
%
% DESIGN NOTES
%
% Nonrecursive all-zero in-place time-domain filter.
% The filter is implemented in a direct form realization.
%
%           N       -i
%   H(z) = SUM b(i)z
%          i=0
%
%   x(t) ->---(z0)----- b0 >------+-----> y(t)
%              |                  |
%              z1------ b1 >------+
%              |                  |
%              z2------ b2 >------+
%              |                  |
%              :                  :
%              |                  |
%              zN------ bN >------+
%
% VARIABLES
%
% INPUTS
%   b          -     N+1 tap weights
%   n          -     Filter order, N
%   z          -     Filter memory
%   xy         -     Input sequence
%   len        -     Input sequence length
%
% OUTPUTS
%   z          -     Filter memory
%   xy         -     Output sequence
%
% INTERNALS
%   t          -     Sequence index value
%   ar         -     Weighted sum accumulator
%
% ******************************************************************

function [ z, xy ] = zerofilt( b, n, z, xy, len )

for t = 1:len
    z(1) = xy(t);
    ar = sum( z(2:n+1) .* b(2:n+1) );
    z(2:n+1) = z(1:n);
    xy(t) = ar + ( z(1) * b(1) );
end

